///////////////////////////////////////////
///////////////////////////////////////////
// GLOBALS AND FILE LOCATIONS
///////////////////////////////////////////
///////////////////////////////////////////

version 12
macro drop _all						// Must do this BEFORE setting the dir globals below!
pause on
set more off
* No longer have to set mem in Stata v12
* To install: SSC INSTALL (gllamm | estout | estwrite) net install dm79, from(http://www.stata.com/stb/stb56) =SVMAT2 | net install spost9_ado, from(http://www.indiana.edu/~jslsoc/stata) =MISSCHK | dm88_1.pkg (RENVARS) | estwrite, from(http://fmwww.bc.edu/RePEc/bocode/e)

global filename 	"combined v1-2"		// Extra vars added to BSA and TUC from v1-1, April 2016									
global dodir		"C:\Users\bpb\Dropbox\WS\2015 Benefits beliefs"
global BSAdir 		"C:\Users\bpb\Desktop\Datasets misc\BSA"
global EFCMORIdir	"C:\Users\bpb\Dropbox\WS\Stigma proposal 2012\1. MORI survey"
global TUCdir		"C:\Users\bpb\Dropbox\WS\Stigma proposal 2012\1. TUC YouGov survey"
global RSSMORIdir	"C:\Users\bpb\Dropbox\WS\Stigma proposal 2012\1. MORI-RSS survey 2013"
global MORI2015dir	"C:\Users\bpb\Dropbox\WS\Stigma proposal 2012\1. MORI perceptions survey 2015"
global EFCYouGovdir	"C:\Users\bpb\Dropbox\WS\Stigma proposal 2012\1. EFC YouGov survey"
global ESSdir		"C:\Users\bpb\Desktop\Datasets misc\ESS\ESS08"
global EBdir		"C:\Users\bpb\Desktop\Datasets Misc\Eurobarometer"
global Curran2010dir "C:\Users\bpb\Desktop\Datasets Misc\Eurobarometer\Curran et al study (SN7007)\stata9"
global workingdir	"${BSAdir}\Combined surveys working"
global datasets 	"bsa EFCMORI2012 TUC RSSMORI2013 MORI2015 EFCYouGov2012 ESS08 EB2007 EB2009 Curran2010" 		

// Follow-on dirs
global logdir		"${dodir}\z. Logs and ref"
	capture log close
	local cmth = month(date("`c(current_date)'", "DMY"))
	local cyr  = year(date("`c(current_date)'", "DMY"))
	log using "${logdir}\Benefit beliefs `cyr'-`cmth'.txt", text append

exit



///////////////////////////////////////////
///////////////////////////////////////////
// GETTING THE DATA
///////////////////////////////////////////
///////////////////////////////////////////

* The separate data cleaning
do "${dodir}\1_BSA_cleaning.do"
do "${dodir}\1_EFCMORI2012_cleaning.do"
do "${dodir}\1_TUC_cleaning.do"
do "${dodir}\1_RSSMORI2013_cleaning.do"
do "${dodir}\1_MORI2015_cleaning.do"
do "${dodir}\1_EFCYouGov_cleaning.do"
do "${dodir}\1_ESS08_cleaning.do"
do "${dodir}\1_Curran2010_cleaning.do"
do "${dodir}\1_EB2007_cleaning.do"
do "${dodir}\1_EB2009_cleaning.do"

* Merging and joint data cleaning
do "${dodir}\1_a_master_cleaning.do"
save "${workingdir}\\${filename}_combined", replace	


	
///////////////////////////////////////////
///////////////////////////////////////////
// ANALYSES FOR PAPER 1a - descriptives
///////////////////////////////////////////
///////////////////////////////////////////

/*
use "${workingdir}\\${filename}_combined", replace	
keep if _nation==9
estimates clear
estread using "${workingdir}\\${filename}_estimates", id(uniqueid) 
*/

use "${workingdir}\\${filename}_combined", replace	
do "${dodir}\3_analysis_part1.do"
estwrite *_prop *_desc *_benlev *_catT using "${workingdir}\\${filename}_estimates", id(uniqueid) replace
estimates clear
save "${workingdir}\\${filename}_combined_poststage1", replace

// Bootstrap estimates around correctness - takes a little while
do "${dodir}\3_analysis_part2.do"

// Text output to look at
list fraudis_text if fraudis_text~="" & fraudis_text~=" ", noobs notrim

// Other quick calculations 
* Descriptives for Web Appendix 2
keep if _nation==9
table _data if _data~="bsa"  							[pw=_weight], c(mean _age min _age max _age mean _male) format(%4.3f)
table _data if _data~="bsa" & _age>=18 & _age<=75 		[pw=_weight], c(mean _age mean _male) format(%4.3f)
table _svyyear if _data=="bsa" 							[pw=_weight], c(mean _age min _age max _age mean _male) format(%4.3f)
table _svyyear if _data=="bsa" & _age>=18 & _age<=75 	[pw=_weight], c(mean _age mean _male) format(%4.3f)
tab _svyyear if _age==17 & _data=="bsa"	// Somehow a few 17 year olds creeping in - but very few
* For the out-of-work bens blog post
svyset [pw=_weight]
svy: tab outofwrk2014
svy: tab outofwrk_trend
* Signifiance testing of fraud vars
gen combi_fraud 		= estfraud		if _data=="EFCMORI2012"
	replace combi_fraud		= estfraud13	if _data=="RSSMORI2013"
	replace combi_fraud		= fraudspend 	if _data=="TUC"
	replace combi_fraud		= falseJSA		if _data=="bsa"
reg combi_fraud ib(4)._dataset [pw=_weight]
	lincom _b[8._dataset] - _b[7._dataset]
* Better off
prop betteroff [pw=_weight], nolabel
* Duration on benefits
prop JSAyr [pw=_weight], nolabel
* Perceived min wage rate
use "${BSAdir}\BSA 1999 (SN4318)\stata8\bsa99a.dta", replace
	prop mwageamt [pw=wtfactor] if mwageamt<999.98, nolabel



///////////////////////////////////////////
///////////////////////////////////////////
// FOR LEVEUN VAN OORSCHOT BOOK CHAPTER JAN 2016
// Started 27/12/2015
///////////////////////////////////////////
///////////////////////////////////////////


*------------------------------------------------------------------------------------------------------------------------
* PREP
*------------------------------------------------------------------------------------------------------------------------

use "${workingdir}\\${filename}_combined", replace	
keep if _data=="ESS08" | _data=="TUC" | _data=="bsa"
drop if _data=="bsa" & (_svyyear~=2000 & _svyyear~=2001 & _svyyear~=2005 & _svyyear~=2007 & _svyyear~=2013)
recode morewelf (-2 -1=.n)(8 9=.r)(1/2=1 "1_(strongly)agree")(3/5=0 "0_not agree"), gen(morewelfB)
rename P* P*B
// Clearing variables only used for other datasets
drop _partyvote _partywldvote _sgrade _week estfraud* fraudis* mtb* outofwrk* saveleast savemost spmost* unempbetter unemprate* unemprising ///
	unemprate* JSAvPen oth_LE65-oth_blackasian oth_christian-oth_ftsalary oth_house-oth_paper oth_rent-oth_twitter oth_violcrim-oth_vote morewelf
save "${workingdir}\\${filename}_combined_ForLeuvenCh", replace	
	
	
*------------------------------------------------------------------------------------------------------------------------
* ANALYSES FOR PAPER 1b - regressions
*------------------------------------------------------------------------------------------------------------------------
do "${dodir}\4a_Leuven_book_analysis.do"
do "${dodir}\4b_Leuven_book_ESSintl.do"


