////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// NEW DATA CLEANING - dataset not used previously
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

// Load the dataset - I've already turned to Stata to remove identifying information from the version they sent over
use "${EFCYouGovdir}\EFCYouGov-v1-00", replace
numlabel _all, add mask(#_)


// Renaming the relevant variables
rename EF1??	mtb??
	rename mtb0? mtb?
	forvalues i=1/10 {
		replace mtb`i'=.d if mtb12==1 | mtb13==1
	/**/ }
	drop mtb11-mtb13
/* NO LONGER USED - IT'S JUST TOO TERRIBLE
rename EF53		fraudVerror
	label var fraudVerror "More benefit money lost through govt error than false claims"
*/

// Checking correct values - people are surprisingly accurate!
dis "MTBs"
sum mtb1 mtb2 mtb4 mtb6 mtb9 mtb10
dis "Contributory benefits"
sum mtb3 mtb5 mtb7 mtb8



****************************************************
** OTHER VARS / FINAL THINGS
****************************************************

// Renaming variables for merging with other datasets
rename age		_age
recode profile_gender (1=1)(2=0), gen(_male)
rename pmxid	_uniqueid
rename W8		_weight
rename profile_socialgrade_cie	_sgrade

// Making categorial vars have similar groupings
recode profile_GOR (1=1)(2=2)(3=3)(4=4)(5=5)(6=7)(7=13)(8=10)(9=6)(10=11)(11=12)(12=14), gen(_region) 	// To match BSA categories (see OneNote)
recode profile_education_level (16 17=1)(3 6 7 11/15=2)(2 4 5 8/10=3)(1 18=4)(19=.d)(20=.r), gen(_quals)
rename profile_work_stat_r		_work1		// Other datasets are made comparable to this coding
clonevar _work2 = _work1
egen _outofwrkben 	= anymatch(EF21 EF22 EF23), values(1)
	replace _outofwrkben = . if missing(EF21)
egen _irben 		= anymatch(EF24 EF25 EF26 EF27), values(1)
	replace _irben = . if missing(EF21)
egen _anyben 		= anymatch(_outofwrkben _irben), values(1)
	replace _anyben = . if missing(EF21)
recode household (1/3=1)(4/6=2)(7/9=3)(10/15=4)(16=.d)(17=.r), gen(_incquartiles)
recode profile_newspaper_readership (16=0)(1=1)(2=2)(3=3)(5=5)(6=7)(8=9)(9=10)(10=11)(4=12)(7 11/15=99), gen(_paper)

// Ending
keep mtb* _*
compress
aorder
save "${workingdir}\\${filename}_EFCYouGov2012", replace
/*
use "${workingdir}\\${filename}_EFCYouGov2012", replace
*/

