////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// CORRECT VALUES
// Ending with L or H denotes Low and High for plausible range
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

* This is used below to determine what 'true' is considered to be 
* 	: starting setting is within 2.5 percentage points (producing a 5 percentage point window)
*	: other assumptions are used for questions that are about £ (in TUC survey)
global correct_range		=5


***************************************************
** FRAUD VARIABLES
***************************************************
/* 	NOTE: As you can see, the code below is annoyingly fiddly - but this was the only way I could do adjust for different range
	sizes easily, while at the same time doing slightly different things for each variable.  All I can say is: it works!
	If you're struggling to follow it, then just look at the values in "$correct_<var>L" and "$correct_<var>H" and this
	should become clear...  These are also included in the paper */

// BSA 2007
local var "falseIB"
global correct_`var'		"0.1"
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	
local var "falseJSA"
global correct_`var' 		=3
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	
dis "Correct is ${correct_`var'}, lower bound is ${correct_`var'L}, higher bound is ${correct_`var'H}"

// EFCMORI2012
local var "estfraud"
global correct_`var' 		=2
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

// RSSMORI2013
local var "estfraud13"
global correct_`var' 		=2
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

// TUC2012
local var "fraudspend"
global correct_`var' 		=1
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	


	
***************************************************
** AMOUNT SPENT ON DIFFERENT BENS 
***************************************************

////////////////////////////
// CATEGORICAL BSA variables 2001 - from the Peter Taylor-Gooby paper that asked these questions
* Overall spending - I've checked this, and the figures in the paper are correct (if some detabable aspects)
global correct_spenmost		"8"		// Social security
global correct_spennext		"1 3"	// Health is correct (3), but education is close (12.5% of spending vs. 14.7% for health)
global correct_speneither2	"1 3 8"	// Any of the above
global correct_spenlast		"4 5 10" // 10_Overseas aid (at 0.7%) is close to 4_housing (0.9%) and 5_public transport (1.0%)
* Benefit spending - see OneNote, I've had to do this myself...
global correct_socbmost		"1"		// Retirement pensions
global correct_socbnext		"2 4"	// PTG makes 2 (child benefots) the most accurate response - I make it the MOST accurate 2nd response, after 4 (disabled people) 
global correct_socbeither2	"1 2 4"	// Any of the above
global correct_socblast		"3 5"	// PTG puts single parents (3) as top but also counts unemp bens (3) as accurate response, but from the figures he gives this is some way out

////////////////////////////
// CATEGORICAL RSSMORI2013
global correct_spmost		"5 7 8"	// Question asks for 2-3 biggest areas of spending - I've (generously) allowed people who gave ANY of the 3 biggest areas of spending, even if they only gave two answers 
global correct_savemost		"7"
global correct_saveleast	"2 3"	// Not much to choose between these two options (means-testing bus pass and winter fuel allowance)
global correct_JSAvPen		"2"

////////////////////////////
// CONTINUOUS TUC 2012
local var "unempspend"
global correct_`var'		"3-6"				// 3 is a bit low, but it's one interpretation of the right answer
	if ${correct_range}>3			global correct_`var'L 	=0			
	else							global correct_`var'L 	=3 - ${correct_range}
	if ${correct_range}>3			global correct_`var'H	=6 + ${correct_range} 
	else							global correct_`var'H	=6 + ${correct_range} + (${correct_range} - 3)



***************************************************
** UNEMP RATES, VALUE OF BENEFITS (exc. BSA) AND OTHERS
***************************************************

////////////////////////////
// Claim rates - CATEGORICAL
global correct_unemprate1			"1"			// If expressed as % of total pop then would be 6%, but 8% is the lowest figure anyway (response '1')
* The next two variables are also covered as continuous variables below
global correct_sickdsb				"1 2"
global correct_uemplwk				"1 2"

////////////////////////////
// Claim rates - CONTINUOUS - UK results only - from Eurostat (see my spreadsheet that's merged in), or for out-of-work bens, see separate spreadsheet
local var "sickdsbN"
global correct_`var'		=5.7
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	
	
local var "uemplwkN"
global correct_`var'		=4.3
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	
	
local var "unemprate2_2007"
global correct_`var'		=5.4
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "unemprate2_2009"
global correct_`var'		=7.7
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "unemprate3"					// Ipsos MORI 2013 version
global correct_`var'		=6			// They accidentally put this as 8% in their 'correct figures' - only a minor error though
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "outofwrk2014"
global correct_`var'		=11.4			// Corrected from 11.8% when May 2015 figures were released, in Dec 2015
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "outofwrk2000"
global correct_`var'		=14.3
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "outofwrk_trend"
global correct_`var'		= ${correct_outofwrk2014} - ${correct_outofwrk2000} 
	global correct_`var'L 	= -7
	global correct_`var'H	= -1
	/* I've removed the original version, as this is a trend rather than an absolute percentage, so closer to the money estimates
	global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	global correct_`var'H	=${correct_`var'} + ${correct_range}	*/
	


////////////////////////////
// TUC2012
local var "JSAyr"
global correct_`var'		"32-40"				
	global correct_`var'L 	=32 - ${correct_range}
	global correct_`var'H	=40 + ${correct_range} 

local var "JSAfamily"
global correct_`var'		=111.45		// Correct value is £111.45 - I've gone for a window of round numbers as that's what people guess in 
	global correct_`var'L 	=100
	global correct_`var'H	=125 

global correct_betteroffC	"1"			// 1=Better off

local var "betteroff"
global correct_`var'		=128		// I make the accurate figure £128, slightly lower than TUC at £138 - but only a small impact on correctness
	global correct_`var'L 	=100
	global correct_`var'H	=150 


////////////////////////////
// EFCMORI2012
global correct_mtb			"1 2 3 4 5 6 9 10"		// IS, income-based JSA, WTC, Pension Credit, CTB, CTC - CB, IB are in both groups due to announced policy changes
global correct_nonmtb		"3 5 7 8"				// NOT contribution-based JSA, SSP - CB, IB are in both groups due to announced policy changes









////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// NON-BENEFIT KNOWLEDGE QUESTIONS
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////


////////////////////////////
// CONTINUOUS BSA variables 2001 - from the Peter Taylor-Gooby paper that asked these questions
local var "oth_car100"
global correct_`var'		=70
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_chpov100_2001"
global correct_`var'		=21
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_hipay100_2001"
global correct_`var'		=8
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_propr100"
global correct_`var'		=13
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_prpen100"
global correct_`var'		=57
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_prsch100_2001"
global correct_`var'		=9
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_vicri100"
global correct_`var'		=22
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

* These are taken from my own analysis of Census data for England & Wales as they're not in PTG's paper - see OneNote
local var "oth_blasi100"
global correct_`var'		"7-9"				// 7 is just Black and Asian people, 9 also includes Chinese people and those who identify as Mixed
	if ${correct_range}>7			global correct_`var'L 	=0			
	else							global correct_`var'L 	=7 - ${correct_range}
	if ${correct_range}>7			global correct_`var'H	=9 + ${correct_range} 	
	else							global correct_`var'H	=9 + ${correct_range} + (${correct_range} - 7)
	

////////////////////////////
// RSSMORI2013 - all taken from MORI's 'actual figures' unless otherwise specified
local var "oth_age"
global correct_`var'		=16
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_vote"
global correct_`var'		"51-65"		// Depends on whether we look at share of pop or share of electorate
	if ${correct_range}>51			global correct_`var'L 	=0			
	else							global correct_`var'L 	=51 - ${correct_range}
	if ${correct_range}>51			global correct_`var'H	=65 + ${correct_range} 	
	else							global correct_`var'H	=65 + ${correct_range} + (${correct_range} - 51)

local var "oth_paper"
global correct_`var'		=35
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_twitter"
global correct_`var'		=16
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_facebook"
global correct_`var'		=49
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_christian"
global correct_`var'		=59
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_muslim"
global correct_`var'		=5
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_blackasian"
global correct_`var'		=11
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_migr"
global correct_`var'		"13-15"		// They don't give a source for the upper bound
	if ${correct_range}>13			global correct_`var'L 	=0			
	else							global correct_`var'L 	=13 - ${correct_range}
	if ${correct_range}>13			global correct_`var'H	=15 + ${correct_range} 
	else							global correct_`var'H	=15 + ${correct_range} + (${correct_range} - 13)	

global correct_oth_migrC 	"5"

local var "oth_asylum"
global correct_`var'		=4
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

global correct_oth_asylumC 	"2 3"		// This is either 2-4% or 5-7% - true figure is 4%

global correct_oth_asylumrise "0"		

local var "oth_U16preg"
global correct_`var'		=0.6
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

local var "oth_violcrim"
global correct_`var'		=33
	if ${correct_range}>${correct_`var'}		local `var'correction = (${correct_range} - ${correct_`var'}) 
	if "``var'correction'"==""		global correct_`var'L 	=${correct_`var'} - ${correct_range}			
	else							global correct_`var'L 	=0
	if "``var'correction'"==""		global correct_`var'H	=${correct_`var'} + ${correct_range}	
	else							global correct_`var'H	=${correct_`var'} + ${correct_range}	+ ``var'correction'	

global correct_oth_violrise	"0"
global correct_oth_crimfall	"1"
	
	
