////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////
// ANALYSIS PART 2
// Bootstrapping descriptive results
////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////

*---------------------------------------------------------------------------------------------------------
* As elsewhere
*---------------------------------------------------------------------------------------------------------
keep if _nation==9
do "${dodir}\2_correct_values.do"


*---------------------------------------------------------------------------------------------------------
* Defining the program to bootstrap
*---------------------------------------------------------------------------------------------------------
capture program drop mythsBS
program define mythsBS, eclass
	
		syntax [varlist] [if] [in]
		tokenize "`varlist'"
		local depvar	"`1'"				
		dis "`depvar'"

		* Prevalence of don't knows and correct / incorrect answers
		quietly {
		capture drop `depvar'T
		gen 			`depvar'T = 1 if `depvar'>=${correct_`depvar'L} & `depvar'<=${correct_`depvar'H}
			replace  	`depvar'T = 2 if `depvar'<${correct_`depvar'L} 
			replace		`depvar'T = 3 if `depvar'>${correct_`depvar'H} & ~missing(`depvar')
			replace		`depvar'T = 4 if `depvar'==.d	
		/**/ }
		
		proportion `depvar'T [pw=_weight]
			matrix props = e(b)'
			// This ridiculous bit of code is necessary to put things in the right places as some of the categories are empty...
			local problabels = e(label1)
			local prop1 = strpos(subinstr("`problabels'"," ","",.), "1")
			local prop2 = strpos(subinstr("`problabels'"," ","",.), "2")
			local prop3 = strpos(subinstr("`problabels'"," ","",.), "3")
			local prop4 = strpos(subinstr("`problabels'"," ","",.), "4")
			if `prop1'>0		ereturn scalar correct 			= props[`prop1',1]*100			
			if `prop2'>0		ereturn scalar underestimate 	= props[`prop2',1]*100			
			if `prop3'>0		ereturn scalar overestimate		= props[`prop3',1]*100			
			if `prop4'>0		ereturn scalar dontknow 		= props[`prop4',1]*100			
			// Just other bits to add
			ereturn local  truefigure	= "${correct_`depvar'}"			
			ereturn scalar truerange_low = ${correct_`depvar'L} 		
			ereturn scalar truerange_hi 	= ${correct_`depvar'H}		
		drop `depvar'T
end


*---------------------------------------------------------------------------------------------------------
* Bootstrapping
*---------------------------------------------------------------------------------------------------------
global allcats		"unemprate2_2009 betteroff"
global noDK			"outofwrk2014 outofwrk2000 outofwrk_trend JSAfamily JSAyr"
global noDKunder	"fraudspend unempspend"
global nounder		"estfraud falseIB falseJSA estfraud13 unemprate2_2007 unemprate3"


* For ones that have all categories
matrix define allcats= (. \ . \ . \ .)
global colnames "start"
local thesevars "${allcats}"
foreach var in `thesevars' {
	set seed 28072015 				// Arbitrary number (based on today's date when writing the code), to ensure replication of exact results
	time
	bootstrap e(correct) e(underestimate) e(overestimate) e(dontknow), reps(1000): mythsBS `var'
	quietly estat bootstrap, bc
	matrix allcats = allcats, e(b)' , e(ci_bc)'
	global colnames "${colnames} `var' ll ul"
	time
/**/ }
matrix colnames allcats = ${colnames} 
matrix rownames allcats = Correct Underestimate Oversimate DontKnow

* For ones that miss out Don't Know
matrix define noDK = (. \ . \ .)
global colnames "start"
local thesevars "${noDK}"
foreach var in `thesevars' {
	set seed 28072015 				
	time
	bootstrap e(correct) e(underestimate) e(overestimate), reps(1000): mythsBS `var'
	quietly estat bootstrap, bc
	matrix noDK = noDK , e(b)' , e(ci_bc)'
	global colnames "${colnames} `var' ll ul"
	time
/**/ }
matrix colnames noDK = ${colnames} 
matrix rownames noDK = Correct Underestimate Oversimate 


* For ones that miss out Don't Know AND underestimates
matrix define noDKunder = (. \ . )
global colnames "start"
local thesevars "${noDKunder}"
foreach var in `thesevars' {
	set seed 28072015 				
	time
	bootstrap e(correct) e(overestimate), reps(1000): mythsBS `var'
	quietly estat bootstrap, bc
	matrix noDKunder = noDKunder , e(b)' , e(ci_bc)'
	global colnames "${colnames} `var' ll ul"
	time
/**/ }
matrix colnames noDKunder = ${colnames} 
matrix rownames noDKunder = Correct Oversimate 


* For ones that miss out underestimates
matrix define nounder = (. \ . \ .)
global colnames "start"
local thesevars "${nounder}"
foreach var in `thesevars' {
	set seed 28072015 				
	time
	bootstrap e(correct) e(overestimate) e(dontknow), reps(1000): mythsBS `var'
	quietly estat bootstrap, bc
	matrix nounder = nounder , e(b)' , e(ci_bc)'
	global colnames "${colnames} `var' ll ul"
	time
/**/ }
matrix colnames nounder = ${colnames} 
matrix rownames nounder = Correct Overestimate DontKnow


*---------------------------------------------------------------------------------------------------------
* OUTPUTTING
*---------------------------------------------------------------------------------------------------------
matrix correct = allcats[1, 2...], noDK[1, 2...], nounder[1, 2...], noDKunder[1, 2...]
matrix under   = allcats[2, 2...], noDK[2, 2...]
matrix over    = allcats[3, 2...], noDK[3, 2...], nounder[2, 2...], noDKunder[2, 2...]
matrix dontknow= allcats[4, 2...], 				  nounder[3, 2...]
esttab   matrix(correct) 	using "${dodir}\Outputs\part1_BS_correct.csv", csv replace
esttab   matrix(under) 		using "${dodir}\Outputs\part1_BS_under.csv", csv replace
esttab   matrix(over) 		using "${dodir}\Outputs\part1_BS_over.csv", csv replace
esttab   matrix(dontknow) 	using "${dodir}\Outputs\part1_BS_dontknow.csv", csv replace
