*---------------------------------------------------------------------------------------------------------------------------------------------------
* UK ANALYSIS
* A subset of the variables in the first benefit beliefs paper
*---------------------------------------------------------------------------------------------------------------------------------------------------
estimates clear
use "${workingdir}\\${filename}_combined_ForLeuvenCh", replace	
keep if _nation==9

// VARIABLE LIST
global contvars 	"falseIB falseJSA fraudspend betteroff unempspend JSAfamily JSAyr"
global intcontvars 	"sickdsbN uemplwkN"		// Ones that we can compare across countries in part 1b of the analysis
global benlevvars 	"mum_XG_2000 penc_XG_2005 ub1_XG_2000 ub1_XG_2013 ubc_XG_2005 "
global catvarsESS  	"sickdsb uemplwk"
global catvarsBSA  	"socblast socbmost socbnext spenlast spenmost spennext speneither"


// GROUPING DESERVINGNESS VARIABLE CATEGORIES
foreach var in Dbennent Duentrjb Dsochelp Dunempjob  {
	recode `var' (1/2=1 "1_Agree")(3=2   "2_Neither")(4/5=3 "3_Disagree"), gen(`var'T)
	recode `var' (1/2=1 "1_Agree")(3/5=0 "0_Neither/Disagree"), gen(`var'B)
/**/ }
recode DdependencyT (1=1 "1_System has created culture of dependency")(2/3=0 "0_Neither/Most claimants victims of circumstances"), gen(DdependencyB)


// DESCRIPTIVE STATISTICS
foreach var in _partyid _male _quals _region2 _work1 _mainbenB {
	capture noisily eststo descs_cat_`var': prop `var' [pw=_weight], over(_dataset _svyyear, nolab)
/**/ }
esttab descs_cat* using "${dodir}\Outputs\control_descs1.csv", replace csv nostar not noparentheses nonum unstack
eststo descs_cont: mean _age [pw=_weight], over(_dataset _svyyear, nolab)
table _dataset 					, c(count _partyid count _male count _quals count _region2)
table _dataset					, c(count _age max _age min _age)
table _svyyear if _dataset==10	, c(count _partyid count _male count _quals count _region2)
table _svyyear if _dataset==10	, c(count _age max _age min _age)


// SETTING UP THE ACCURACY VARIABLES FOR BELIEFS
do "${dodir}\2_correct_values.do"
* Defining labels that are used below
label define correctness 1 "1_Correct" 2 "2_Underestimate" 3 "3_Overestimate" 4 "4_DontKnow", modify
label define correctcat  0 "0_Incorrect" 1 "1_Correct" 9 "9_DontKnow", modify
local depvars "${contvars} ${intcontvars}"
foreach depvar in `depvars' {
	capture drop `depvar'T
	gen 			`depvar'T = 1 if `depvar'>=${correct_`depvar'L} & `depvar'<=${correct_`depvar'H}
		replace  	`depvar'T = 2 if `depvar'<${correct_`depvar'L} 
		replace		`depvar'T = 3 if `depvar'>${correct_`depvar'H} & ~missing(`depvar')
		replace		`depvar'T = 4 if `depvar'==.d	
		label values `depvar'T correctness
		label var `depvar'T "Correctness of `var'"
		gen `depvar'Tnol = `depvar'T
/**/ }


* ADDED APRIL 2016: Accuracy count for TUC survey
tab1 fraudspendT betteroffT unempspendT JSAfamilyT JSAyrT // Just to check responses
gen TUCcorrect = 0 
	foreach var in fraudspend /*betteroff*/ unempspend JSAfamily JSAyr {
		replace TUCcorrect = TUCcorrect + 1 if `var'T==1
	/**/ }
egen TUCcount = rownonmiss(fraudspend /*betteroff*/ unempspend JSAfamily JSAyr)
	replace TUCcorrect = . if TUCcount<4
egen TUCpattern = concat(fraudspendT /*betteroffT*/ unempspendT JSAfamilyT JSAyrT)
* Results to expor
tab TUCcorrect if _data=="TUC" 
prop TUCcorrect if _data=="TUC" [pw=_weight]
tab TUCpattern if _data=="TUC" 
recode TUCcorrect (3 4=3 "3_3&4 combined"), gen(TUCcorrect2)
* Estimated beliefs
svyset [pw=_weight]
svy: tab TUCcorrect DdependencyB, row pearson
svyset, clear
logit DdependencyB i.TUCcorrect2 i._partyid c._age c._age#c._age i._quals _male i._region2 i._work1 if _partyid<5 [pw=_weight]
margins TUCcorrect2

	
**************************************************************
* Generating descriptive results for continuous variables
/* Similar code to initial ben beliefs paper, 
adapted to look across subgroups
**************************************************************/

* The program for continuous data
capture program drop cont_dependency
program define cont_dependency, eclass

	syntax [namelist]
	tokenize "`namelist'"
	local beliefvar		"`1'"
	local dependency	"`2'"
	dis "beliefvar is `beliefvar', dependency is `dependency'"

	if "`dependency'"~="Pbengen" & "`dependency'"~="Pbenrise" { // Introduced April 2016 with the extra vars
		* Mean of outcome, divided by dependency
		eststo SGP_`beliefvar'_`dependency':	mean `beliefvar' [pw=_weight], over(`dependency'T)
			test _b[_subpop_1] = _b[_subpop_2]
			estadd scalar sig_agrVdis = r(p)												: SGP_`beliefvar'_`dependency'
			test _b[_subpop_3] = _b[_subpop_2]
			estadd scalar sig_neiVdis = r(p)												: SGP_`beliefvar'_`dependency'
		// NOTE: have removed confidence intervals in place of significance tests, and also medians for simplicity (just using means, unlike the first paper on benefit beliefs)

		* Prevalence of don't knows and correct / incorrect answers, divided by dependency
		eststo `beliefvar'Tnol_`dependency':	proportion `beliefvar'Tnol [pw=_weight], over(`dependency'T)
			local problabels = e(label1)
			estadd local prop1 = strpos(subinstr("`problabels'"," ","",.), "1")				: `beliefvar'Tnol_`dependency'
			estadd local prop2 = strpos(subinstr("`problabels'"," ","",.), "2")				: `beliefvar'Tnol_`dependency'
			estadd local prop3 = strpos(subinstr("`problabels'"," ","",.), "3")				: `beliefvar'Tnol_`dependency'
			estadd local prop4 = strpos(subinstr("`problabels'"," ","",.), "4")				: `beliefvar'Tnol_`dependency'
			estadd local truefigure	= "${correct_`beliefvar'}"								: `beliefvar'Tnol_`dependency'
			estadd scalar truerange_low = ${correct_`beliefvar'L}							: `beliefvar'Tnol_`dependency'
			estadd scalar truerange_hi 	= ${correct_`beliefvar'H}							: `beliefvar'Tnol_`dependency'
	/**/ }
	
	* Regression of dependency on belief (various versions):
	sum `beliefvar' if `beliefvar'Tnol==1		
		local max_`beliefvar' = r(max)			// This sets the counterfactual for use in the margins command in what follows
	// The list of regressions
	local reg1 "`beliefvar'"
	local reg2 "`beliefvar' 	i._partyid c._age c._age#c._age i._quals				_male i._region2 i._work1"
	local reg3 "`beliefvar' if _partyid<5"
	local reg4 "`beliefvar' 	i._partyid c._age c._age#c._age i._quals 				_male i._region2 i._work1 if _partyid<5"
	local reg5 "c.`beliefvar'##(i._partyid c._age c._age#c._age i._quals)				_male i._region2 i._work1"
	local reg6 "`beliefvar' 	i._partyid c._age c._age#c._age i._quals 				_male i._region2 i._work1 i._mainbenB"
	local reg7 "c.`beliefvar'##(i._partyid c._age c._age#c._age i._quals i._mainbenB) 	_male i._region2 i._work1"
	// The models, looped
	forvalues i = 1/7 {
		if ("`dependency'"=="Ddependency" | "`dependency'"=="Pbengen" | "`dependency'"=="Pbenrise") & `i'>=6			dis _newline(20) "No observations for cycle `i' of `dependency' & `beliefvar' so skipped"
		else {
			eststo R`i'_`beliefvar'_`dependency': 	logit `dependency'B `reg`i'' [pw=_weight]
			* Interactions with beliefs for `beliefvar' and `dependency', for control variables #`i'
			if `i' == 5 | `i'==7 {
				testparm _partyid#c.`beliefvar' 
					estadd scalar int_partyid = r(p)
				testparm c.`beliefvar'#c._age c.`beliefvar'#c._age#c._age 
					estadd scalar int_age = r(p)
				testparm _quals#c.`beliefvar'
					estadd scalar int_quals = r(p)
				if `i'==5 	{
					testparm _partyid#c.`beliefvar' c.`beliefvar'#c._age c.`beliefvar'#c._age#c._age _quals#c.`beliefvar' 
				/**/ }
				if `i'==7 	{
					testparm _mainbenB#c.`beliefvar'
						estadd scalar int_mainbenB = r(p)
					testparm _partyid#c.`beliefvar' c.`beliefvar'#c._age c.`beliefvar'#c._age#c._age _quals#c.`beliefvar' _mainbenB#c.`beliefvar'
				/**/ }	
						estadd scalar int_demogs= r(p)											: R`i'_`beliefvar'_`dependency'
				eststo MR`i'_`beliefvar'_`dependency': margins, dydx(c.`beliefvar') at(_age=(20 40 60)) at(_quals=(1(1)4)) at(_partyid=(1 2 3 5 6)) post vsquish
			/**/ }
			* Overall average marginal effect
			estimates restore R`i'_`beliefvar'_`dependency'
			margins, dydx(`beliefvar') post
				matrix output = e(b)
				estadd scalar belief_effect = output[1,1]								: R`i'_`beliefvar'_`dependency'
			* Simulation for counterfactual
			estadd scalar counterfactual_belief =  `max_`beliefvar''						: R`i'_`beliefvar'_`dependency'	// Noting the counterfactual for the simulation
			estimates restore R`i'_`beliefvar'_`dependency'
			margins, at(`beliefvar'=`max_`beliefvar'') at((asobs) `beliefvar') post
				matrix output = e(b)
				estadd scalar iftrue = output[1,1]											: R`i'_`beliefvar'_`dependency'
				estadd scalar actual = output[1,2]											: R`i'_`beliefvar'_`dependency'
				test _b[1._at] = _b[2._at]
					estadd scalar sig_counterfactual = r(p)									: R`i'_`beliefvar'_`dependency'
				lincom _b[1._at] - _b[2._at]
				estadd scalar ci_lb = r(estimate) + invnorm(0.025)*r(se)					: R`i'_`beliefvar'_`dependency'
				estadd scalar ci_ub = r(estimate) + invnorm(0.975)*r(se)					: R`i'_`beliefvar'_`dependency'
		/**/ }
	/**/ }		
	// NOTE: have removed dummy vars for refusals and don't knows, as don't think these are used
end

* Running this for each pair of variables
local pair1  "sickdsbN 		Dbennent"
local pair2  "uemplwkN 		Dbennent"
local pair3  "sickdsbN 		Duentrjb "
local pair4  "uemplwkN 		Duentrjb "
local pair5  "falseIB  		Dsochelp "
local pair6  "falseJSA 		Dsochelp "
local pair7  "falseIB  		Dunempjob"
local pair8  "falseJSA 		Dunempjob"
local pair9  "fraudspend 	Ddependency"
local pair10 "betteroff 	Ddependency"
local pair11 "unempspend 	Ddependency"
local pair12 "JSAfamily 	Ddependency"
local pair13 "JSAyr			Ddependency"
* Added sensitivity analyses Apri l2016
local pair14 "JSAfamily		Pbengen"
local pair15 "betteroff		Pbengen"
local pair16 "JSAfamily		Pbenrise"
local pair17 "betteroff		Pbenrise"

// The loop
forvalues pair = 1/17 {
	dis "Pair `pair' is `pair`i''"
	cont_dependency `pair`pair''
/**/ }


* Outputting
esttab *Tnol*					using "${dodir}\Outputs\Leuven_prop1.csv", replace csv compress nostar not nodepvars nonum varwidth(15) modelwidth(25) ///
	scalars(__________ prop1 prop2 prop3 prop4 ___________ truefigure truerange_low truerange_hi)
esttab SGP*						using "${dodir}\Outputs\Leuven_desc1.csv", replace csv compress nostar not nodepvars nonum varwidth(15) modelwidth(25) ///
	scalars(sig_agrVdis sig_neiVdis) sfmt(%4.3f)
esttab R1* R2* R3* R4* R6*		using "${dodir}\Outputs\Leuven_regs1.csv", replace csv compress nostar 	   nodepvars nonum varwidth(15) modelwidth(25) ///
	p(%4.3f) noparentheses scalars(belief_effect counterfactual_belief iftrue actual sig_counterfactual ci_lb ci_ub int_demogs) sfmt(%5.4f)
set matsize 1000
esttab R5* R7*					using "${dodir}\Outputs\Leuven_regs1b.csv", replace csv compress nostar 	   nodepvars nonum varwidth(15) modelwidth(25) ///
	p(%4.3f) noparentheses scalars(belief_effect counterfactual_belief iftrue actual sig_counterfactual ci_lb ci_ub int_partyid int_age int_quals int_mainbenB int_demogs) sfmt(%5.4f)
esttab MR* 						using "${dodir}\Outputs\Leuven_regs1bM.csv", replace csv compress nonum nodepvars varwidth(15) modelwidth(25) not ///
	noparentheses nostar	
	

	
	

**************************************************************
* Benefit amount variables
**************************************************************
estimates clear

* The program for categorical data
capture program drop amt_dependency
program define amt_dependency, eclass

	syntax [namelist]
	tokenize "`namelist'"
	local beliefvar		"`1'"
	local dependency	"`2'"
	dis "beliefvar is `beliefvar', dependency is `dependency'"

	* Mean of outcome, divided by dependency
	eststo SGP_`beliefvar'_`dependency':	prop (`dependency'B) [pw=_weight], over(`beliefvar') 

	* Regression of dependency on belief (various versions):
	local reg1 "ib(2).`beliefvar'"
	local reg2 "ib(2).`beliefvar' 	i._partyid c._age c._age#c._age i._quals i._mainbenB	_male i._region2 i._work1"
	local reg3 "ib(2).`beliefvar' 																							if _partyid<5"
	local reg4 "ib(2).`beliefvar' 	i._partyid c._age c._age#c._age i._quals i._mainbenB	_male i._region2 i._work1 		if _partyid<5"
	local reg5 "ib(2).`beliefvar'##(i._partyid c._age c._age#c._age i._quals i._mainbenB) 	_male i._region2 i._work1"
	// The models, looped
	forvalues i = 1/5 {
		eststo R`i'_`beliefvar'_`dependency': 	logit `dependency'B `reg`i'' [pw=_weight]
			testparm i(1 3 4).`beliefvar'
				estadd scalar sig_all = r(p)									: R`i'_`beliefvar'_`dependency'
			* Interactions with beliefs for `beliefvar' and `dependency', for control variables #`i'
			if `i' == 5  {
				testparm _partyid#`beliefvar' 
					estadd scalar int_partyid = r(p)
				testparm `beliefvar'#c._age c.`beliefvar'#c._age#c._age 
					estadd scalar int_age = r(p)
				testparm _quals#`beliefvar'
					estadd scalar int_quals = r(p)
				testparm _mainbenB#`beliefvar'
					estadd scalar int_mainbenB = r(p)
				testparm _partyid#`beliefvar' `beliefvar'#c._age `beliefvar'#c._age#c._age _quals#`beliefvar' _mainbenB#`beliefvar'
						estadd scalar int_demogs= r(p)											: R`i'_`beliefvar'_`dependency'
				*eststo MR`i'_`beliefvar'_`dependency': margins i.`beliefvar', at(_age=(20 40 60)) at(_quals=(1(1)4)) at(_partyid=(1 2 3 5 6)) post vsquish
				*estimates restore R`i'_`beliefvar'_`dependency'
			/**/ }
		eststo M`i'_`beliefvar'_`dependency': 	margins `beliefvar', post
			test _b[1.`beliefvar'] = _b[3.`beliefvar']
			estadd scalar sig_underVover = r(p)								: M`i'_`beliefvar'_`dependency'
	/**/ }	
end

* Running this for each pair of variables
unab benlevvars: ${benlevvars}
// The loop
foreach belvar in `benlevvars' {
	foreach depvar in Dsochelp Dunempjob morewelf {
		dis "Pair is `belvar' `depvar'"
		amt_dependency `belvar' `depvar'
	/**/ }
/**/ }


* Outputting
set matsize 1000
esttab SGP*		using "${dodir}\Outputs\Leuven_desc2.csv", replace csv compress nostar not nodepvars nonum varwidth(15) modelwidth(25) ///
	sfmt(%4.3f)
esttab R*		using "${dodir}\Outputs\Leuven_regs2.csv", replace csv compress nostar p(%4.3f) noparentheses nodepvars nonum ///
	varwidth(15) modelwidth(25) scalars(sig_all) sfmt(%5.4f) drop(*2000#* *2005#* *2013#*) 
esttab M*		using "${dodir}\Outputs\Leuven_margins2.csv", replace csv compress nostar not nodepvars nonum varwidth(15) modelwidth(25) ///
	scalars(sig_underVover) sfmt(%5.4f)


	

**************************************************************
* Categorical variables (single response given)
* (None of the vars with multiple responses inc in this chapter)
**************************************************************
estimates clear

* Setting accuracy
unab catvars: ${catvarsESS} ${catvarsBSA} 
foreach depvar in `catvars' {
	capture drop `depvar'T
	egen `depvar'T = anymatch(`depvar'), values(${correct_`depvar'})
	replace `depvar'T = . if missing(`depvar') & `depvar'~=.d
	replace `depvar'T = 9 if `depvar'==.d
	label values `depvar'T correctcat
	eststo `depvar'_catT:		proportion `depvar'T [pw=_weight], nolabel
/**/ }

* The program for categorical data
capture program drop cat_dependency
program define cat_dependency, eclass

	syntax [namelist]
	tokenize "`namelist'"
	local beliefvar		"`1'"
	local dependency	"`2'"
	dis "beliefvar is `beliefvar', dependency is `dependency'"

	* Mean of outcome, divided by dependency
	eststo SGP_`beliefvar'_`dependency':	prop (`dependency'B) [pw=_weight], over(`beliefvar') 

	* Regression of dependency on belief (various versions):
	local reg1 "ib(1).`beliefvar'"
	local reg2 "ib(1).`beliefvar' 	i._partyid c._age c._age#c._age i._quals i._mainbenB	_male i._region2 i._work1"
	local reg3 "ib(1).`beliefvar' 																							if _partyid<5"
	local reg4 "ib(1).`beliefvar' 	i._partyid c._age c._age#c._age i._quals i._mainbenB	_male i._region2 i._work1 		if _partyid<5"
	local reg5 "ib(1).`beliefvar'##(i._partyid c._age c._age#c._age i._quals i._mainbenB) 	_male i._region2 i._work1"
	// The models, looped
	forvalues i = 1/5 {
		eststo R`i'_`beliefvar'_`dependency': 	logit `dependency'B `reg`i'' [pw=_weight]
		eststo M`i'_`beliefvar'_`dependency': 	margins `beliefvar', post
	/**/ }	
end

// The loop
unab catvars: ${catvarsBSA}
foreach belvar in `catvars' {
	foreach depvar in Dsochelp Dunempjob {
		dis "Pair is `belvar'T `depvar'"
		cat_dependency `belvar'T `depvar'
	/**/ }
/**/ }
unab catvars: ${catvarsESS}
foreach belvar in `catvars' {
	foreach depvar in Dbennent Duentrjb {
		dis "Pair is `belvar'T `depvar'"
		cat_dependency `belvar'T `depvar'
	/**/ }
/**/ }


* Outputting
esttab SGP*		using "${dodir}\Outputs\Leuven_desc3.csv", replace csv compress nostar not nodepvars nonum varwidth(15) modelwidth(25) ///
	sfmt(%4.3f)
esttab R*		using "${dodir}\Outputs\Leuven_regs3.csv", replace csv compress nostar p(%4.3f) noparentheses nodepvars nonum ///
	varwidth(15) modelwidth(25) scalars(sig_all) sfmt(%5.4f)
esttab M*		using "${dodir}\Outputs\Leuven_margins3.csv", replace csv compress nostar not nodepvars nonum varwidth(15) modelwidth(25)


// For final stages only	
estwrite _all using "${dodir}\Outputs\models_April_2016", replace








*---------------------------------------------------------------------------------------------------------------------------------------------------
/* OLD TWOSTEP ANALYSES
*---------------------------------------------------------------------------------------------------------------------------------------------------

use "${workingdir}\\${filename}_combined_poststage1", replace
global controlvars		"_age _male i._quals"
	
// The model
time
local controls "${controlvars}"
*unab contvars: ${contvars}
local contvars "estfraud estfraud13 falseIB"
foreach depvar in `contvars' {
	dis _newline(5) in red "Variable is `depvar'"
	* Different variables have different control variables - this produces a list of control variables available for this dependent variable
	local keepcontrols ""
	foreach possiblevar in `controls' {
		local trimmedvar = subinstr("`possiblevar'", "i.","",1) 
		quietly tab `trimmedvar' if ~missing(`depvar')
		if r(r)>0		local keepcontrols "`keepcontrols' `possiblevar'"
	/**/ }
	* The models themselves
	eststo `depvar'_2st: 		heckman `depvar' `keepcontrols'  			, select(`depvar'D= `keepcontrols' i.numref) twostep // The ML version wasn't converging & was much slower and didn't converge
		*margins, dydx(_male) predict(psel)				// Probability of NOT saying 'don't know'
		*margins, dydx(_male) predict(ycond) force		// This is basically the same as the 2nd stage coefficient, so no real need for it
	eststo `depvar'_st1_nowt:	reg     `depvar'  `keepcontrols' 
	eststo `depvar'_st2_nowt:	logit   `depvar'D `keepcontrols' 
	eststo `depvar'_st1_wt:		reg     `depvar'  `keepcontrols' [pw=_weight]
	eststo `depvar'_st2_wt:		logit   `depvar'D `keepcontrols' [pw=_weight]
	* Categorical model
	eststo `depvar'_cat:		mlogit  `depvar'T `keepcontrols' [pw=_weight], base(1)
		eststo `depvar'_M1: capture margins i._quals if e(sample), predict(outcome(1)) post
		estimates restore `depvar'_cat
		eststo `depvar'_M2: capture margins i._quals if e(sample), predict(outcome(2)) post
		estimates restore `depvar'_cat
		eststo `depvar'_M3: capture margins i._quals if e(sample), predict(outcome(3)) post
		estimates restore `depvar'_cat
		eststo `depvar'_M4: capture margins i._quals if e(sample), predict(outcome(4)) post
/**/ }
time


// Outputting
esttab *_twostage, 	eq(1, 2) not star(+ 0.10 * 0.05 ** 0.01) nodepvars nonum varwidth(15) modelwidth(18)
esttab *_st?_wt, 	not star(+ 0.10 * 0.05 ** 0.01) nodepvars nonum varwidth(15) modelwidth(18)
esttab *_cat, 		not nostar nodepvars nonum varwidth(15) modelwidth(18)
esttab *_M1, 		not nostar nodepvars nonum varwidth(15) modelwidth(18)
